/* gvSIG. Geographic Information System of the Valencian Government
*
* Copyright (C) 2007-2008 Infrastructures and Transports Department
* of the Valencian Government (CIT)
* 
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
* MA  02110-1301, USA.
* 
*/

/*
* Prodevelop, S.L.
* Pza. Juan de Villarrasa, 14 - 5
* Valencia
* Spain
* Tel: +34 963510612
* e-mail: prode@prodevelop.es
* http://www.prodevelop.es
*
*/
package es.prodevelop.gvsig.mini.geom.impl.base;

import com.vividsolutions.jts.geom.Geometry;

import es.prodevelop.gvsig.mini.exceptions.BaseException;
import es.prodevelop.gvsig.mini.geom.api.IGeometry;
import es.prodevelop.gvsig.mini.geom.impl.base.Point;

/**
 * An array of points. Usually used to represent the route points on the screen
 * @author ALberto Romeu Carrasco (aromeu@prodevelop.es)
 */
public class MultiPoint implements IGeometry {

    private Point[] points;
    private boolean visible = true;

    /**
     * The constructor
     * @param points An array of points
     */
    public MultiPoint(final Point[] points) {        
        this.points = points;
    }

    /**
     * Clears this instance
     */
    public void destroy() {
        final Point[] points = this.points;
        final int size = points.length;
        
        for (int i = 0; i < size; i++) {
            points[i].destroy();
        }
        this.points = null;
    }

    /**
     * 
     * @return True if is visible
     */
    public boolean isVisible() {
        return visible;
    }

    /**
     * Sets to visible or not this instance and every Point in the array
     * @param visible
     */
    public void setVisible(final boolean visible) {
        this.visible = visible;
        final Point[] points = this.points;
        final int size = points.length;
        for (int i = 0; i < size; i++) {
            points[i].setVisible(visible);
        }
    }    

    /**
     * The length of the array of points
     * @return The number of points 
     */
    public int getNumPoints() {
        return getPoints().length;
    }

    /**
     * 
     * @param i The index of the point
     * @return The point at the index specified
     */
    public Point getPoint(final int i) {
        return (Point) points[i];
    }

    /**
     * 
     * @return The array of Point
     */
    public Point[] getPoints() {
        return points;
    }

    /**
     * Sets the array of Point
     * @param points An array of Point
     */
    public void setPoints(final Point[] points) {
        this.points = points;
    }

    /**
     * 
     * @return The array of Point
     */
    public Point[] getCoordinates() {
        return points;
    }

    /**
     * Sets the array of Point
     * @param coords An array of Point
     */
    public void setCoordinates(final Point[] coords) {
        this.points = coords;
    }
    
    public Geometry getGeometry() throws BaseException {
		throw new BaseException("No JTS Geometry");
	}
}
